# Generated by Django 4.0.5 on 2022-06-17 10:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_tenants', '0004_alter_tenant_slug'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tenant',
            name='description',
        ),
        migrations.RemoveField(
            model_name='tenant',
            name='name',
        ),
    ]



# Generated by Django 4.0.5 on 2022-06-15 19:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_tenants', '0003_tenant_slug'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tenant',
            name='slug',
            field=models.CharField(max_length=100, unique=True),
        ),
    ]
